@@ -33,14 +33,12 @@ class FireServiceRota(object):
 
     def __init__(self, base_url = None, username: str = None, password: str = None, token_info: dict = None):
         """Init module"""
-
         self._base_url = base_url
         self._username = username
         self._password = password
         self._token_info = token_info
         self._user = None
 
-
     def request_tokens(self) -> bool:
         """Request API tokens."""
 
@@ -59,7 +57,6 @@ class FireServiceRota(object):
             _LOGGER.debug(f"Error obtaining tokens: {err}")
             return False
 
-
     def refresh_tokens(self) -> bool:
         """Refresh existing API tokens."""
 
@@ -81,7 +78,6 @@ class FireServiceRota(object):
             _LOGGER.debug(f"Error refreshing tokens: {err}")
             return False
 
-
     def _get_userid(self):
         """Get user data."""
 
@@ -90,7 +86,6 @@ class FireServiceRota(object):
 
         _LOGGER.debug(f"Userid data: {self._user}")
 
-
     def get_schedules(self):
         """Get user schedules."""
 
@@ -107,7 +102,6 @@ class FireServiceRota(object):
 
         return response
 
-
     def get_skills(self):
         """Get skills."""
 
@@ -116,7 +110,6 @@ class FireServiceRota(object):
 
         return response
 
-
     def get_standby_function(self, id):
         """Get standby function."""
 
@@ -127,20 +120,18 @@ class FireServiceRota(object):
 
         return response
 
-
     def set_incident_response(self, id, status):
         """Set incident response for one incident."""
 
         url = FSR_ENDPOINT_INCIDENT_RESPONSES.format(id)
 
         if status:
-            json = {'status': 'acknowledged', 'channel': 'home-assistant'}
+            json = {'status': 'acknowledged'}
         else:
-            json = {'status': 'rejected', 'channel': 'home-assistant'}
+            json = {'status': 'rejected'}
 
         self._request('POST', endpoint=url, log_msg_action='set incident response', params=json, auth_request=False)
         
-
     def get_incident_response(self, id):
         """Get status of incident response for one incident."""
 
@@ -154,7 +145,6 @@ class FireServiceRota(object):
 
         return None
 
-
     def get_availability(self):
         """Get user availablity."""
 
@@ -194,7 +184,6 @@ class FireServiceRota(object):
         interval['available'] = False
         return interval
 
-
     def _request(
         self,
         method: str,
@@ -317,11 +306,9 @@ class FireServiceRotaIncidents(Thread, websocket.WebSocketApp):
         self.on_incident = on_incident
         self._recent_incidents = deque(maxlen=30)
 
-
     def on_open(self):
         _LOGGER.debug('Websocket open')
 
-
     def on_message(self, message):
         _LOGGER.debug('Websocket data:' + message)
         try:
@@ -329,14 +316,17 @@ class FireServiceRotaIncidents(Thread, websocket.WebSocketApp):
             if "type" not in message:
                 if "identifier" in message and json.loads(message["identifier"])["channel"] == "IncidentNotificationsChannel":
                     incident = message["message"]
-                    """skip messages without message_to_speech_url and address info"""
-                    if "address" in incident and "message_to_speech_url" in incident:
-                        incident_id = incident["id"]
-                        if incident_id not in self._recent_incidents:
-                            self._recent_incidents.append(incident_id)
-                            self.on_incident(incident)
-                        else:
-                            _LOGGER.debug("Skipping duplicate incident")
+                    """mark new and update messages"""
+#                   if "address" in incident and "message_to_speech_url" in incident:
+                    incident_id = incident["id"]
+                    if incident_id not in self._recent_incidents:
+                        self._recent_incidents.append(incident_id)
+                        incident['trigger'] = 'new'
+                        _LOGGER.debug("New incident received")
+                    else:
+                        incident['trigger'] = 'update'
+                        _LOGGER.debug("Incident update received")
+                    self.on_incident(incident)
                 else:
                     _LOGGER.debug(f"Malformed data received\n{message}")
             elif message["type"] == "welcome":
@@ -352,7 +342,6 @@ class FireServiceRotaIncidents(Thread, websocket.WebSocketApp):
         except Exception as e:
             _LOGGER.exception(e)
 
-
     def run_forever(self, sockopt=None, sslopt=None, ping_interval=0, ping_timeout=None):
 #        websocket.enableTrace(True)
         websocket.WebSocketApp.run_forever(self, sockopt=sockopt, sslopt=sslopt, ping_interval=ping_interval,
